<?php

namespace Bellarmine\Faculty\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bellarmine\Faculty\Http\Requests\FACULTYAdminRequest;
use Bellarmine\Faculty\Interfaces\FACULTYRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class FACULTYAdminController extends AdminController
{
    /**
     * Initialize f_a_c_u_l_t_y controller.
     *
     * @param type FACULTYRepositoryInterface $f_a_c_u_l_t_y
     *
     * @return type
     */
    public function __construct(FACULTYRepositoryInterface $f_a_c_u_l_t_y)
    {
        $this->model = $f_a_c_u_l_t_y;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(FACULTYAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('faculty.f_a_c_u_l_t_y.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('faculty::f_a_c_u_l_t_y.names').' :: ');

        return $this->theme->of('faculty::admin.f_a_c_u_l_t_y.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(FACULTYAdminRequest $request, $id)
    {
        $f_a_c_u_l_t_y = $this->model->find($id);

        if (empty($f_a_c_u_l_t_y)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('faculty::admin.f_a_c_u_l_t_y.new');
        }

        if ($request->wantsJson()) {
            return $f_a_c_u_l_t_y;
        }

        Former::populate($f_a_c_u_l_t_y);

        return view('faculty::admin.f_a_c_u_l_t_y.show', compact('f_a_c_u_l_t_y'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FACULTYAdminRequest $request)
    {
        $f_a_c_u_l_t_y = $this->model->findOrNew(0);
        Former::populate($f_a_c_u_l_t_y);

        return view('faculty::admin.f_a_c_u_l_t_y.create', compact('f_a_c_u_l_t_y'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FACULTYAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $f_a_c_u_l_t_y = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('faculty::f_a_c_u_l_t_y.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(FACULTYAdminRequest $request, $id)
    {
        $f_a_c_u_l_t_y = $this->model->find($id);

        Former::populate($f_a_c_u_l_t_y);

        return view('faculty::admin.f_a_c_u_l_t_y.edit', compact('f_a_c_u_l_t_y'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(FACULTYAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $f_a_c_u_l_t_y = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('faculty::f_a_c_u_l_t_y.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(FACULTYAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('faculty::f_a_c_u_l_t_y.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
